Module node

Module node 

The nodes themsleves, and their data.

Structs

Attribute
A tag attribute, e.g. class="test" in <div class="test" ...>.
Attributes
CanvasData
ComputedStyles
The struct that Servo uses to represent computed values.
CustomWidgetData
DocumentData
Data specific to the Document root node.
ElementData
ImageResourceData
ListItemLayout
Node
NodeFlags
ProxyRenderContext
A RenderContext that proxies resource registrations through to an inner RenderContext and also keeps track of the ResourceIds of all sucessfully registered resources so that they can be automatically unregistered if the Widget’s node is dropped.
RasterImageData
ScrollbarRef
A specific scrollbar: one axis of one scroll container.
SvgImageData
A parsed SVG image.
SvgIntrinsicDimensions
Dimensions declared on the root <svg> element, before any resolution.
TextBrush
Parley Brush type for Blitz which contains the Blitz node id
TextInputData
TextLayout
TextNodeData

Enums

CustomWidgetStatus
DisplayOuter
GeneratedTextInputEvent
ImageData
ListItemLayoutPosition
Marker
NodeData
The different kinds of nodes in the DOM.
NodeKind
ScrollbarColor
The computed value of scrollbar-color (css-scrollbars-1), with colors fully resolved (no currentColor).
ScrollbarWidth
The computed value of scrollbar-width (css-scrollbars-1).
SpecialElementData
Heterogeneous data that depends on the element’s type.
SpecialElementType
Status

Traits

Widget