ProxyRenderContext

Struct ProxyRenderContext 

pub struct ProxyRenderContext<'widget, 'rend> {
    pub resource_ids: &'widget mut Vec<ResourceId>,
    pub inner: &'rend mut dyn RenderContext,
}
A RenderContext that proxies resource registrations through to an inner RenderContext and also keeps track of the ResourceIds of all sucessfully registered resources so that they can be automatically unregistered if the Widget’s node is dropped.

Fields

resource_ids: &'widget mut Vec<ResourceId>inner: &'rend mut dyn RenderContext