pub struct ShadowRootData {
pub host: NodeId,
pub mode: ShadowRootMode,
pub stylesheet_nodes: Vec<NodeId>,
}Expand description
Data associated with a NodeData::ShadowRoot node.
A shadow root is a non-element, non-document node that acts as the root of a
shadow tree. Its children (on the owning Node) are the top-level nodes
of the shadow tree. The light-DOM children of the host element are
distributed into any <slot> elements within this tree to form the
“flattened tree” that is used for style resolution, layout and painting.
Fields
host: NodeIdThe node id of the host element that this shadow root is attached to.
mode: ShadowRootModeThe encapsulation mode of this shadow root.
stylesheet_nodes: Vec<NodeId>Node ids of <style> elements within this shadow root, in document
order. Used to build the scoped stylesheet set for this shadow tree.
Implementations
Sourceimpl ShadowRootData
impl ShadowRootData
pub fn new(host: NodeId, mode: ShadowRootMode) -> Self