The nodes themsleves, and their data.
Structs
- Attribute
- A tag attribute, e.g.
class="test"in<div class="test" ...>. - Attributes
- Canvas
Data - Computed
Styles - The struct that Servo uses to represent computed values.
- Custom
Widget Data - Document
Data - Data specific to the
Documentroot node. - Element
Data - Image
Resource Data - List
Item Layout - Node
- Node
Flags - Proxy
Render Context - A
RenderContextthat proxies resource registrations through to an innerRenderContextand also keeps track of theResourceIds of all sucessfully registered resources so that they can be automatically unregistered if the Widget’s node is dropped. - Raster
Image Data - Scrollbar
Ref - A specific scrollbar: one axis of one scroll container.
- SvgImage
Data - A parsed SVG image.
- SvgIntrinsic
Dimensions - Dimensions declared on the root
<svg>element, before any resolution. - Text
Brush - Parley Brush type for Blitz which contains the Blitz node id
- Text
Input Data - Text
Layout - Text
Node Data
Enums
- Custom
Widget Status - Display
Outer - Generated
Text Input Event - Image
Data - List
Item Layout Position - Marker
- Node
Data - The different kinds of nodes in the DOM.
- Node
Kind - Scrollbar
Color - The computed value of
scrollbar-color(css-scrollbars-1), with colors fully resolved (nocurrentColor). - Scrollbar
Width - The computed value of
scrollbar-width(css-scrollbars-1). - Special
Element Data - Heterogeneous data that depends on the element’s type.
- Special
Element Type - Status