Module node

Module node 

The nodes themsleves, and their data.

Structs

Attribute
A tag attribute, e.g. class="test" in <div class="test" ...>.
Attributes
BackgroundImageData
CanvasData
ComputedStyles
The struct that Servo uses to represent computed values.
CustomWidgetData
ElementData
ListItemLayout
Node
NodeFlags
ProxyRenderContext
A RenderContext that proxies resource registrations through to an inner RenderContext and also keeps track of the ResourceIds of all sucessfully registered resources so that they can be automatically unregistered if the Widget’s node is dropped.
RasterImageData
TextBrush
Parley Brush type for Blitz which contains the Blitz node id
TextInputData
TextLayout
TextNodeData

Enums

CustomWidgetStatus
DisplayOuter
ImageData
ListItemLayoutPosition
Marker
NodeData
The different kinds of nodes in the DOM.
NodeKind
SpecialElementData
Heterogeneous data that depends on the element’s type.
SpecialElementType
Status

Traits

Widget