pub struct Node {Show 25 fields
pub id: usize,
pub parent: Option<usize>,
pub children: Vec<usize>,
pub layout_parent: Cell<Option<usize>>,
pub layout_children: RefCell<Option<Vec<usize>>>,
pub paint_children: RefCell<Option<Vec<usize>>>,
pub stacking_context: Option<Box<HoistedPaintChildren>>,
pub flags: NodeFlags,
pub data: NodeData,
pub stylo_element_data: StyloData,
pub selector_flags: Cell<ElementSelectorFlags>,
pub guard: SharedRwLock,
pub element_state: ElementState,
pub has_snapshot: bool,
pub snapshot_handled: AtomicBool,
pub dirty_descendants: AtomicBool,
pub before: Option<usize>,
pub after: Option<usize>,
pub style: Style<Atom>,
pub display_constructed_as: Display,
pub cache: Cache,
pub unrounded_layout: Layout,
pub final_layout: Layout,
pub scroll_offset: Point<f64>,
pub transform: Option<Affine>,
/* private fields */
}Fields
id: usizeOur Id
parent: Option<usize>Our parent’s ID
children: Vec<usize>layout_parent: Cell<Option<usize>>Our parent in the layout hierachy: a separate list that includes anonymous collections of inline elements
layout_children: RefCell<Option<Vec<usize>>>A separate child list that includes anonymous collections of inline elements
paint_children: RefCell<Option<Vec<usize>>>The same as layout_children, but sorted by z-index
stacking_context: Option<Box<HoistedPaintChildren>>flags: NodeFlagsdata: NodeDataNode type (Element, TextNode, etc) specific data
stylo_element_data: StyloDataselector_flags: Cell<ElementSelectorFlags>guard: SharedRwLockelement_state: ElementStatehas_snapshot: boolsnapshot_handled: AtomicBooldirty_descendants: AtomicBoolWhether any descendant of this node needs restyling. Used by Stylo’s incremental style traversal to skip unchanged subtrees.
before: Option<usize>after: Option<usize>style: Style<Atom>display_constructed_as: Displaycache: Cacheunrounded_layout: Layoutfinal_layout: Layoutscroll_offset: Point<f64>transform: Option<Affine>Implementations
Sourceimpl Node
impl Node
pub fn pe_by_index(&self, index: usize) -> Option<usize>
pub fn set_pe_by_index(&mut self, index: usize, value: Option<usize>)
pub fn is_or_contains_block(&self) -> bool
pub fn is_whitespace_node(&self) -> bool
pub fn is_focussable(&self) -> bool
pub fn set_restyle_hint(&mut self, hint: RestyleHint)
Sourcepub fn has_dirty_descendants(&self) -> bool
pub fn has_dirty_descendants(&self) -> bool
Returns whether this node has any descendants that need restyling.
Sourcepub fn set_dirty_descendants(&self)
pub fn set_dirty_descendants(&self)
Sets the dirty_descendants flag on this node.
Sourcepub fn unset_dirty_descendants(&self)
pub fn unset_dirty_descendants(&self)
Clears the dirty_descendants flag on this node.
Sourcepub fn mark_ancestors_dirty(&self)
pub fn mark_ancestors_dirty(&self)
Marks all ancestors of this node as having dirty descendants. This propagates the dirty flag up the tree so that the style traversal knows to visit the subtree containing this node.
pub fn damage(&self) -> Option<RestyleDamage>
pub fn set_damage(&mut self, damage: RestyleDamage)
pub fn insert_damage(&mut self, damage: RestyleDamage)
pub fn remove_damage(&mut self, damage: RestyleDamage)
pub fn clear_damage_mut(&mut self)
pub fn hover(&mut self)
pub fn unhover(&mut self)
pub fn is_hovered(&self) -> bool
pub fn focus(&mut self, shell_provider: Arc<dyn ShellProvider>)
pub fn blur(&mut self, shell_provider: Arc<dyn ShellProvider>)
pub fn is_focussed(&self) -> bool
pub fn active(&mut self)
pub fn unactive(&mut self)
pub fn is_active(&self) -> bool
pub fn disable(&mut self)
pub fn enable(&mut self)
pub fn subdoc(&self) -> Option<&dyn Document>
pub fn subdoc_mut(&mut self) -> Option<&mut dyn Document>
pub fn text_input_v_centering_offset(&self, scale: f64) -> f64
Sourceimpl Node
impl Node
pub fn tree(&self) -> &Slab<Node>
pub fn with(&self, id: usize) -> &Node
pub fn print_tree(&self, level: usize)
pub fn index_of_child(&self, child_id: usize) -> Option<usize>
pub fn child_index(&self) -> Option<usize>
pub fn forward(&self, n: usize) -> Option<&Node>
pub fn backward(&self, n: usize) -> Option<&Node>
pub fn is_element(&self) -> bool
pub fn is_anonymous(&self) -> bool
pub fn is_text_node(&self) -> bool
pub fn element_data(&self) -> Option<&ElementData>
pub fn element_data_mut(&mut self) -> Option<&mut ElementData>
pub fn text_data(&self) -> Option<&TextNodeData>
pub fn text_data_mut(&mut self) -> Option<&mut TextNodeData>
pub fn node_debug_str(&self) -> String
pub fn outer_html(&self) -> String
pub fn write_outer_html(&self, writer: &mut String)
pub fn attrs(&self) -> Option<&[Attribute]>
pub fn attr(&self, name: LocalName) -> Option<&str>
pub fn primary_styles( &self, ) -> Option<impl Deref<Target = ServoArc<ComputedValues>>>
pub fn text_content(&self) -> String
pub fn flush_style_attribute(&mut self, url_extra_data: &UrlExtraData)
pub fn order(&self) -> i32
pub fn z_index(&self) -> i32
pub fn is_stacking_context_root(&self, is_flex_or_grid_item: bool) -> bool
Sourcepub fn hit(&self, x: f32, y: f32) -> Option<HitResult>
pub fn hit(&self, x: f32, y: f32) -> Option<HitResult>
Takes an (x, y) position (relative to the parent’s top-left corner) and returns:
- None if the position is outside of this node’s bounds
- Some(HitResult) if the position is within the node but doesn’t match any children
- The result of recursively calling child.hit() on the the child element that is positioned at that position if there is one.
TODO: z-index (If multiple children are positioned at the position then a random one will be recursed into)
Sourcepub fn inline_root_ancestor(&self) -> Option<&Node>
pub fn inline_root_ancestor(&self) -> Option<&Node>
Find the inline root ancestor of this node (or self if this is an inline root). Returns None if no inline root ancestor exists.
Sourcepub fn text_offset_at_point(&self, x: f32, y: f32) -> Option<usize>
pub fn text_offset_at_point(&self, x: f32, y: f32) -> Option<usize>
Get the text byte offset at a given point, using coordinates already transformed to be relative to this inline root’s content box. Returns Some(byte_offset) if the point hits text, None otherwise.
Sourcepub fn absolute_position(&self, x: f32, y: f32) -> Point<f32>
pub fn absolute_position(&self, x: f32, y: f32) -> Point<f32>
Computes the Document-relative coordinates of the Node
Sourcepub fn synthetic_click_event(&self, mods: Modifiers) -> DomEventData
pub fn synthetic_click_event(&self, mods: Modifiers) -> DomEventData
Creates a synthetic click event
pub fn synthetic_click_event_data(&self, mods: Modifiers) -> BlitzPointerEvent